@@ -7,8 +7,12 @@
 // Own
 #include "ColorSchemeEditor.h"
 
+#include "../config-konsole.h"
+
 // Qt
+#include <QColorDialog>
 #include <QCompleter>
+#include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QFileInfo>
 #include <QFileSystemModel>
@@ -16,14 +20,11 @@
 #include <QIcon>
 #include <QImageReader>
 #include <QMetaEnum>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 // KDE
 #include <KLocalizedString>
-#include <KWindowSystem>
-#include <QColorDialog>
-#include <QDialogButtonBox>
-#include <QPushButton>
-#include <QVBoxLayout>
 
 // Konsole
 #include "../characters/CharacterColor.h"
@@ -41,7 +42,7 @@ const int COLOR_COLUMN = 1; // column 1 : actual colors
 const int INTENSE_COLOR_COLUMN = 2; // column 2 : intense colors
 const int FAINT_COLOR_COLUMN = 3; // column 2 : faint colors
 
-ColorSchemeEditor::ColorSchemeEditor(QWidget *parent)
+ColorSchemeEditor::ColorSchemeEditor(bool supportsTransparentWindows, QWidget *parent)
     : QDialog(parent)
     , _isNewScheme(false)
     , _ui(nullptr)
@@ -129,7 +130,7 @@ ColorSchemeEditor::ColorSchemeEditor(QWidget *parent)
     _ui->transparencyWarningWidget->setCloseButtonVisible(false);
     _ui->transparencyWarningWidget->setMessageType(KMessageWidget::Warning);
 
-    if (KWindowSystem::compositingActive()) {
+    if (supportsTransparentWindows) {
         _ui->transparencyWarningWidget->setVisible(false);
     } else {
         _ui->transparencyWarningWidget->setText(i18nc("@info:status",
