@@ -8,7 +8,6 @@
 // Own
 #include "SessionController.h"
 
-#include "konsoledebug.h"
 #include "profile/ProfileManager.h"
 #include "terminalDisplay/TerminalColor.h"
 #include "terminalDisplay/TerminalFonts.h"
@@ -68,6 +67,7 @@
 #include "SaveHistoryTask.h"
 #include "ScreenWindow.h"
 #include "SearchHistoryTask.h"
+#include "konsoledebug.h"
 
 #include "filterHotSpots/ColorFilter.h"
 #include "filterHotSpots/EscapeSequenceUrlFilter.h"
@@ -452,14 +452,12 @@ void SessionController::setupPrimaryScreenSpecificActions(bool use)
     QAction *clearAction = collection->action(QStringLiteral("clear-history"));
     QAction *resetAction = collection->action(QStringLiteral("clear-history-and-reset"));
     QAction *selectAllAction = collection->action(QStringLiteral("select-all"));
-    QAction *selectModeAction = collection->action(QStringLiteral("select-mode"));
     QAction *selectLineAction = collection->action(QStringLiteral("select-line"));
 
     // these actions are meaningful only when primary screen is used.
     clearAction->setEnabled(use);
     resetAction->setEnabled(use);
     selectAllAction->setEnabled(use);
-    selectModeAction->setEnabled(use);
     selectLineAction->setEnabled(use);
 }
 
@@ -674,6 +672,14 @@ void SessionController::setupCommonActions()
     action->setVisible(false);
     connect(action, &QAction::triggered, this, &SessionController::copy);
 
+    action = collection->addAction(QStringLiteral("split-view-left-right"));
+    action->setText(i18n("Split View Left-Right"));
+    connect(action, &QAction::triggered, this, &SessionController::requestSplitViewLeftRight);
+
+    action = collection->addAction(QStringLiteral("split-view-top-bottom"));
+    action->setText(i18n("Split View Top-Bottom"));
+    connect(action, &QAction::triggered, this, &SessionController::requestSplitViewTopBotton);
+
     action = collection->addAction(QStringLiteral("edit_copy_contextmenu_in_out"));
     action->setText(i18n("Copy except prompts"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
@@ -754,7 +760,7 @@ void SessionController::setupCommonActions()
     action->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
     setEditProfileActionText(SessionManager::instance()->sessionProfile(session()));
 
-    _switchProfileMenu = new KActionMenu(i18n("Switch Profile"), this);
+    _switchProfileMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("exchange-positions")), i18n("Switch Profile"), this);
     collection->addAction(QStringLiteral("switch-profile"), _switchProfileMenu);
     connect(_switchProfileMenu->menu(), &QMenu::aboutToShow, this, &Konsole::SessionController::prepareSwitchProfileMenu);
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
@@ -788,6 +794,7 @@ void SessionController::setupCommonActions()
     collection->addAction(QStringLiteral("set-encoding"), _codecAction);
     _codecAction->setCurrentCodec(QString::fromUtf8(session()->codec()));
     connect(session(), &Konsole::Session::sessionCodecChanged, this, &Konsole::SessionController::updateCodecAction);
+#if KCONFIGWIDGETS_VERSION < QT_VERSION_CHECK(5, 103, 0)
     connect(_codecAction,
 #if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
             QOverload<QTextCodec *>::of(&KCodecAction::codecTriggered),
@@ -797,6 +804,11 @@ void SessionController::setupCommonActions()
             this,
 #endif
             &Konsole::SessionController::changeCodec);
+#else
+    connect(_codecAction, &KCodecAction::codecNameTriggered, this, [this](const QString &codecName) {
+        changeCodec(QTextCodec::codecForName(codecName.toUtf8()));
+    });
+#endif
 
     connect(_codecAction, &KCodecAction::defaultItemTriggered, this, [this] {
         Profile::Ptr profile = SessionManager::instance()->sessionProfile(session());
@@ -903,6 +915,7 @@ void SessionController::setupExtraActions()
     action->setText(i18n("Reset Font Size"));
     collection->setDefaultShortcut(action, Qt::CTRL | Qt::ALT | Qt::Key_0);
 
+#ifndef Q_OS_WIN
     // Send signal
     auto *sendSignalActions = collection->add<KSelectAction>(QStringLiteral("send-signal"));
     sendSignalActions->setText(i18n("Send Signal"));
@@ -947,6 +960,7 @@ void SessionController::setupExtraActions()
     action->setText(i18n("User Signal &2") + QStringLiteral(" (USR2)"));
     action->setData(SIGUSR2);
     sendSignalActions->addAction(action);
+#endif
 }
 
 void SessionController::switchProfile(const Profile::Ptr &profile)
@@ -979,7 +993,7 @@ void SessionController::prepareSwitchProfileMenu()
 }
 void SessionController::updateCodecAction(QTextCodec *codec)
 {
-    _codecAction->setCurrentCodec(codec);
+    _codecAction->setCurrentCodec(QString::fromUtf8(codec->name()));
 }
 
 void SessionController::changeCodec(QTextCodec *codec)
@@ -1241,11 +1255,15 @@ void SessionController::selectAll()
 void SessionController::selectMode()
 {
     if (!session().isNull()) {
-        QAction *readonlyAction = actionCollection()->action(QStringLiteral("view-readonly"));
         bool Mode = session()->getSelectMode();
-        session()->setSelectMode(!Mode);
-        readonlyAction->setEnabled(Mode);
-        view()->setSelectMode(!Mode);
+        setSelectMode(!Mode);
+    }
+}
+void SessionController::setSelectMode(bool mode)
+{
+    if (!session().isNull()) {
+        session()->setSelectMode(mode);
+        view()->setSelectMode(mode);
     }
 }
 
@@ -1895,6 +1913,10 @@ void SessionController::sessionAttributeChanged()
         title = session()->title(Session::NameRole);
     }
 
+#ifdef Q_OS_WIN
+    title = session()->userTitle();
+#endif
+
     setTitle(title);
     setColor(session()->color());
     Q_EMIT rawTitleChanged();
@@ -1994,12 +2016,9 @@ void SessionController::showDisplayContextMenu(const QPoint &position)
 
         _preventClose = true;
 
-        if (_showMenuAction != nullptr) {
-            if (_showMenuAction->isChecked()) {
-                popup->removeAction(_showMenuAction);
-            } else {
-                popup->insertAction(_switchProfileMenu, _showMenuAction);
-            }
+        auto hamburger = static_cast<KHamburgerMenu *>(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::HamburgerMenu))));
+        if (hamburger) {
+            hamburger->addToMenu(popup);
         }
 
         // they are here.
